@@ -12,7 +12,7 @@ ENVIRONMENT = os.environ.get("ENVIRONMENT")
 BASE_DIR = Path(__file__).resolve().parent.parent
 environ.Env.read_env(os.path.join(BASE_DIR, ".env"))
 
-project_key = os.environ.get("project_key"),
+project_key = os.environ.get("project_key")
 user_id = os.environ.get("user_id")
 
 
